@@ -2664,18 +2664,18 @@ std::pair<int, double> CSC_RowIterator::NextNonZero() {
 
 // ---- start REModel related functions
 
-int GPB_CreateREModel(int num_data,
-	const int* cluster_ids_data,
+int GPB_CreateREModel(int32_t num_data,
+	const int32_t* cluster_ids_data,
 	const char* re_group_data,
-	int num_re_group,
+	int32_t num_re_group,
 	const double* re_group_rand_coef_data,
-	const int* ind_effect_group_rand_coef,
-	int num_re_group_rand_coef,
-	int num_gp,
+	const int32_t* ind_effect_group_rand_coef,
+	int32_t num_re_group_rand_coef,
+	int32_t num_gp,
 	const double* gp_coords_data,
 	const int dim_gp_coords,
 	const double* gp_rand_coef_data,
-	int num_gp_rand_coef,
+	int32_t num_gp_rand_coef,
 	const char* cov_fct,
 	double cov_fct_shape,
 	double cov_fct_taper_range,
@@ -2816,8 +2816,8 @@ int GPB_GetNumIt(REModelHandle handle,
 }
 
 int GPB_SetPredictionData(REModelHandle handle,
-	int num_data_pred,
-	const int* cluster_ids_data_pred,
+	int32_t num_data_pred,
+	const int32_t* cluster_ids_data_pred,
 	const char* re_group_data_pred,
 	const double* re_group_rand_coef_data_pred,
 	double* gp_coords_data_pred,
@@ -2833,12 +2833,12 @@ int GPB_SetPredictionData(REModelHandle handle,
 
 int GPB_PredictREModel(REModelHandle handle,
 	const double* y_data,
-	int num_data_pred,
+	int32_t num_data_pred,
 	double* out_predict,
 	bool predict_cov_mat,
 	bool predict_var,
 	bool predict_response,
-	const int* cluster_ids_data_pred,
+	const int32_t* cluster_ids_data_pred,
 	const char* re_group_data_pred,
 	const double* re_group_rand_coef_data_pred,
 	double* gp_coords_pred,
