@@ -38,13 +38,14 @@ def train(params, train_set, num_boost_round=100,
     gp_model : GPModel or None, optional (default=None)
         GPModel object for the GPBoost algorithm
     use_gp_model_for_validation : bool, optional (default=True)
-        If True, the gp_model (Gaussian process and/or random effects) is also used (in addition to the tree model)
-        for calculating predictions on the validation data
+        If True, the 'gp_model' (Gaussian process and/or random effects) is also used (in addition to the tree model)
+        for calculating predictions on the validation data. If False, the 'gp_model' (random effects part) is ignored
+        for making predictions and only the tree ensemble is used for making predictions for calculating the validation / test error.
     train_gp_model_cov_pars : bool, optional (default=True)
-        If True, the covariance parameters of the gp_model (Gaussian process and/or random effects) are estimated
-        in every boosting iterations, otherwise the gp_model parameters are not estimated. In the latter case, you
+        If True, the covariance parameters of the 'gp_model' (Gaussian process and/or random effects) are estimated
+        in every boosting iterations, otherwise the 'gp_model' parameters are not estimated. In the latter case, you
         need to either estimate them beforehand or provide the values via the 'init_cov_pars' parameter when creating
-        the gp_model
+        the 'gp_model'
     valid_sets : list of Datasets or None, optional (default=None)
         List of data to be evaluated on during training.
     valid_names : list of strings or None, optional (default=None)
@@ -224,8 +225,6 @@ def train(params, train_set, num_boost_round=100,
     if gp_model is not None:
         # some checks
         if use_gp_model_for_validation and not not valid_sets and not not feval:
-            print(feval)
-            print("DELETE THIS, only for debugging")
             raise ValueError("use_gp_model_for_validation=True is currently "
                              "not supported for custom validation functions. If you need this feature, contact the "
                              "developer of this package or open a GitHub issue.")
@@ -233,7 +232,9 @@ def train(params, train_set, num_boost_round=100,
             raise ValueError("Can use only one validation set when use_gp_model_for_validation = True")
         if not is_valid_contain_train and use_gp_model_for_validation and len(
                 reduced_valid_sets) > 0 and not gp_model.prediction_data_is_set:
-            raise ValueError("Prediction data for gp_model has not been set. Call gp_model.set_prediction_data() first")
+            raise ValueError("Prediction data for 'gp_model' has not been set. "
+                             "This needs to be set prior to trainig when having a validation set and 'use_gp_model_for_validation=True'. "
+                             "Either call 'gp_model.set_prediction_data(...)' first or use 'use_gp_model_for_validation=False'.")
         # update gp_model related parameters
         params['use_gp_model_for_validation'] = use_gp_model_for_validation
         params['train_gp_model_cov_pars'] = train_gp_model_cov_pars
@@ -456,6 +457,7 @@ def _make_n_folds(full_data, folds, nfold, params, seed, gp_model=None, use_gp_m
             num_neighbors_pred = gp_model.num_neighbors_pred
             cov_function = gp_model.cov_function
             cov_fct_shape = gp_model.cov_fct_shape
+            cov_fct_taper_range = gp_model.cov_fct_taper_range
             ind_effect_group_rand_coef = gp_model.ind_effect_group_rand_coef
             gp_model_train = GPModel(group_data=group_data,
                                      group_rand_coef_data=group_rand_coef_data,
@@ -464,6 +466,7 @@ def _make_n_folds(full_data, folds, nfold, params, seed, gp_model=None, use_gp_m
                                      gp_rand_coef_data=gp_rand_coef_data,
                                      cov_function=cov_function,
                                      cov_fct_shape=cov_fct_shape,
+                                     cov_fct_taper_range=cov_fct_taper_range,
                                      vecchia_approx=vecchia_approx,
                                      num_neighbors=num_neighbors,
                                      vecchia_ordering=vecchia_ordering,
@@ -531,17 +534,18 @@ def cv(params, train_set, num_boost_round=100,
     gp_model : GPModel or None, optional (default=None)
         GPModel object for the GPBoost algorithm
     use_gp_model_for_validation : bool, optional (default=True)
-        If True, the gp_model (Gaussian process and/or random effects) is also used (in addition to the tree model)
-        for calculating predictions on the validation data
+        If True, the 'gp_model' (Gaussian process and/or random effects) is also used (in addition to the tree model)
+        for calculating predictions on the validation data. If False, the 'gp_model' (random effects part) is ignored
+        for making predictions and only the tree ensemble is used for making predictions for calculating the validation / test error.
     fit_GP_cov_pars_OOS : bool, optional (default=False)
-        If TRUE, the covariance parameters of the gp_model model are estimated using the out-of-sample (OOS) predictions
+        If TRUE, the covariance parameters of the 'gp_model' model are estimated using the out-of-sample (OOS) predictions
         on the validation data using the optimal number of iterations (after performing the CV).
         This corresponds to the GPBoostOOS algorithm.
     train_gp_model_cov_pars : bool, optional (default=True)
-        If True, the covariance parameters of the gp_model (Gaussian process and/or random effects) are estimated
-        in every boosting iterations, otherwise the gp_model parameters are not estimated. In the latter case, you
+        If True, the covariance parameters of the 'gp_model' (Gaussian process and/or random effects) are estimated
+        in every boosting iterations, otherwise the 'gp_model' parameters are not estimated. In the latter case, you
         need to either estimate them beforehand or provide the values via the 'init_cov_pars' parameter when creating
-        the gp_model
+        the 'gp_model'
     folds : generator or iterator of (train_idx, test_idx) tuples, scikit-learn splitter object or None, optional (default=None)
         If generator or iterator, it should yield the train and test indices for each fold.
         If object, it should be one of the scikit-learn splitter classes
@@ -844,13 +848,14 @@ def grid_search_tune_parameters(param_grid, train_set, params=None, num_try_rand
     gp_model : GPModel or None, optional (default=None)
         GPModel object for the GPBoost algorithm
     use_gp_model_for_validation : bool, optional (default=True)
-        If True, the gp_model (Gaussian process and/or random effects) is also used (in addition to the tree model)
-        for calculating predictions on the validation data
+        If True, the 'gp_model' (Gaussian process and/or random effects) is also used (in addition to the tree model)
+        for calculating predictions on the validation data. If False, the 'gp_model' (random effects part) is ignored
+        for making predictions and only the tree ensemble is used for making predictions for calculating the validation / test error.
     train_gp_model_cov_pars : bool, optional (default=True)
-        If True, the covariance parameters of the gp_model (Gaussian process and/or random effects) are estimated
-        in every boosting iterations, otherwise the gp_model parameters are not estimated. In the latter case, you
+        If True, the covariance parameters of the 'gp_model' (Gaussian process and/or random effects) are estimated
+        in every boosting iterations, otherwise the 'gp_model' parameters are not estimated. In the latter case, you
         need to either estimate them beforehand or provide the values via the 'init_cov_pars' parameter when creating
-        the gp_model
+        the 'gp_model'
     folds : generator or iterator of (train_idx, test_idx) tuples, scikit-learn splitter object or None, optional (default=None)
         If generator or iterator, it should yield the train and test indices for each fold.
         If object, it should be one of the scikit-learn splitter classes
@@ -1009,8 +1014,8 @@ def grid_search_tune_parameters(param_grid, train_set, params=None, num_try_rand
         for param in param_comb:
             params[param] = param_comb[param]
         if verbose_eval >= 1:
-            print("Trying parameter combination number " + str(counter_num_comb) +
-                  " of " + str(len(try_param_combs)) + " parameter combinations...")
+            print("Trying parameter combination " + str(counter_num_comb) +
+                  " of " + str(len(try_param_combs)) + ": " + str(param_comb) + " ...")
         cvbst = cv(params=params, train_set=train_set, num_boost_round=num_boost_round,
                    gp_model=gp_model, use_gp_model_for_validation=use_gp_model_for_validation,
                    train_gp_model_cov_pars=train_gp_model_cov_pars,
@@ -1018,7 +1023,8 @@ def grid_search_tune_parameters(param_grid, train_set, params=None, num_try_rand
                    metrics=metrics, fobj=fobj, feval=feval, init_model=init_model,
                    feature_name=feature_name, categorical_feature=categorical_feature,
                    early_stopping_rounds=early_stopping_rounds, fpreproc=fpreproc,
-                   verbose_eval=verbose_eval_cv, seed=seed, callbacks=callbacks)
+                   verbose_eval=verbose_eval_cv, seed=seed, callbacks=callbacks,
+                   eval_train_metric=False, return_cvbooster=False)
         current_score_is_better = False
         if higher_better:
             current_score = np.max(cvbst[next(iter(cvbst))])
